@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@ class CControllerPopupTriggerWizard extends CController {
 	protected function checkInput() {
 		$fields = [
 			'description' =>	'string',
-			'opdata' =>			'string',
-			'itemid' =>			'db items.itemid',
+			'itemid' =>			'required|db items.itemid',
 			'triggerid' =>		'db triggers.triggerid',
 			'type' =>			'in 0,1',
 			'expressions' =>	'array',
@@ -93,7 +92,7 @@ class CControllerPopupTriggerWizard extends CController {
 			'opdata' => $this->getInput('opdata', ''),
 			'itemid' => $this->getInput('itemid', 0),
 			'type' => $this->getInput('type', 0),
-			'priority' => $this->getInput('priority', 0),
+			'priority' => $this->getInput('priority', TRIGGER_SEVERITY_NOT_CLASSIFIED),
 			'comments' => $this->getInput('comments', ''),
 			'url' => $this->getInput('url', ''),
 			'status' => ($this->hasInput('status') || !$this->hasInput('save'))
@@ -118,6 +117,8 @@ class CControllerPopupTriggerWizard extends CController {
 
 		// Save trigger.
 		if ($this->hasInput('save')) {
+			$trigger_valid = true;
+
 			$item = API::Item()->get([
 				'output' => ['key_'],
 				'selectHosts' => ['host'],
@@ -127,7 +128,6 @@ class CControllerPopupTriggerWizard extends CController {
 
 			$item = reset($item);
 			$host = reset($item['hosts']);
-			$trigger_valid = true;
 
 			// Trigger validation.
 			if ($page_options['description'] === '') {
