@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -119,7 +119,7 @@ foreach ($data['hosts'] as $hostid => $host) {
 $widgets[] = (new CCollapsibleUiWidget(WIDGET_SEARCH_HOSTS, $table))
 	->addClass(ZBX_STYLE_DASHBRD_WIDGET_FLUID)
 	->setExpanded((bool) CProfile::get('web.search.hats.'.WIDGET_SEARCH_HOSTS.'.state', true))
-	->setHeader(_('Hosts'), [], false, 'web.search.hats.'.WIDGET_SEARCH_HOSTS.'.state')
+	->setHeader(_('Hosts'), [], 'web.search.hats.'.WIDGET_SEARCH_HOSTS.'.state')
 	->setFooter(new CList([
 		_s('Displaying %1$s of %2$s found', count($data['hosts']), $data['total_hosts_cnt'])
 	]));
@@ -175,7 +175,7 @@ foreach ($data['groups'] as $groupid => $group) {
 $widgets[] = (new CCollapsibleUiWidget(WIDGET_SEARCH_HOSTGROUP, $table))
 	->addClass(ZBX_STYLE_DASHBRD_WIDGET_FLUID)
 	->setExpanded((bool) CProfile::get('web.search.hats.'.WIDGET_SEARCH_HOSTGROUP.'.state', true))
-	->setHeader(_('Host groups'), [], false, 'web.search.hats.'.WIDGET_SEARCH_HOSTGROUP.'.state')
+	->setHeader(_('Host groups'), [], 'web.search.hats.'.WIDGET_SEARCH_HOSTGROUP.'.state')
 	->setFooter(new CList([
 		_s('Displaying %1$s of %2$s found', count($data['groups']), $data['total_groups_cnt'])
 	]));
@@ -249,7 +249,7 @@ if ($data['admin']) {
 	$widgets[] = (new CCollapsibleUiWidget(WIDGET_SEARCH_TEMPLATES, $table))
 		->addClass(ZBX_STYLE_DASHBRD_WIDGET_FLUID)
 		->setExpanded((bool) CProfile::get('web.search.hats.'.WIDGET_SEARCH_TEMPLATES.'.state', true))
-		->setHeader(_('Templates'), [], false, 'web.search.hats.'.WIDGET_SEARCH_TEMPLATES.'.state')
+		->setHeader(_('Templates'), [], 'web.search.hats.'.WIDGET_SEARCH_TEMPLATES.'.state')
 		->setFooter(new CList([
 			_s('Displaying %1$s of %2$s found', count($data['templates']), $data['total_templates_cnt'])
 		]));
