@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -309,7 +309,7 @@ class CConfigurationExportBuilder {
 				'discovery_rules' => $this->formatDiscoveryRules($host['discoveryRules']),
 				'httptests' => $this->formatHttpTests($host['httptests']),
 				'macros' => $this->formatMacros($host['macros']),
-				'inventory_mode' => $this->formatHostInventoryMode($host['inventory']),
+				'inventory_mode' => $host['inventory_mode'],
 				'inventory' => $this->formatHostInventory($host['inventory']),
 				'tags' => $this->formatTags($host['tags'])
 			];
@@ -702,17 +702,6 @@ class CConfigurationExportBuilder {
 		return $result;
 	}
 
-	/**
-	 * Format host inventory mode.
-	 *
-	 * @param array $inventory
-	 *
-	 * @return string
-	 */
-	protected function formatHostInventoryMode(array $data) {
-		return array_key_exists('inventory_mode', $data) ? $data['inventory_mode'] : '';
-	}
-
 	/**
 	 * Format host inventory.
 	 *
@@ -721,7 +710,7 @@ class CConfigurationExportBuilder {
 	 * @return array
 	 */
 	protected function formatHostInventory(array $inventory) {
-		unset($inventory['hostid'], $inventory['inventory_mode']);
+		unset($inventory['hostid']);
 
 		return $inventory;
 	}
@@ -782,7 +771,8 @@ class CConfigurationExportBuilder {
 				'status' => $hostPrototype['status'],
 				'group_links' => $this->formatGroupLinks($hostPrototype['groupLinks']),
 				'group_prototypes' => $this->formatGroupPrototypes($hostPrototype['groupPrototypes']),
-				'templates' => $this->formatTemplateLinkage($hostPrototype['templates'])
+				'templates' => $this->formatTemplateLinkage($hostPrototype['templates']),
+				'inventory_mode' => $hostPrototype['inventory_mode']
 			];
 		}
 
@@ -1332,7 +1322,7 @@ class CConfigurationExportBuilder {
 			$link['selementpos1'] = $flipped_selements[$link['selementid1']];
 			$link['selementpos2'] = $flipped_selements[$link['selementid2']];
 
-			// Sort selements positons asc.
+			// Sort selements by position asc.
 			if ($link['selementpos2'] < $link['selementpos1']) {
 				zbx_swap($link['selementpos1'], $link['selementpos2']);
 			}
